utils::globalVariables(c("RMSE", "adjR", "control", "controlID",
                         "control_coefs", "feols", "fixed", "index", "p",
                         "ribbon.group", "se", "sig.level", "statistic",
                         "term", "value", "."))

